@@ -17,8 +17,8 @@ from django.conf import settings
 from django.core.files.storage import FileSystemStorage
 from django.utils.translation import ugettext_lazy as _
 from django import forms
-from middleware import threadlocals
-from tasks import audio_convert_task
+from audiofield.middleware import threadlocals
+from audiofield.tasks import audio_convert_task
 import os
 import shutil
 import logging
@@ -71,7 +71,7 @@ class AudioField(FileField):
 
     def __init__(self, *args, **kwargs):
         """Get allowed file extension type (ex. mp3, wav)"""
-        ext_whitelist = kwargs.pop("ext_whitelist")
+        ext_whitelist = kwargs.pop("ext_whitelist", tuple())
         self.ext_whitelist = [i.lower() for i in ext_whitelist]
         super(AudioField, self).__init__(*args, **kwargs)
 
@@ -118,9 +118,18 @@ class AudioField(FileField):
         '''Convert uploaded audio file to selected format'''
 
         request = threadlocals.get_current_request()
-        convert_type = int(request.POST["convert_type"])
-        channel_no = int(request.POST["channel_type"])
-        freq_value = int(request.POST["freq_type"])
+
+        convert_type = 0
+        channel_no = 0
+        freq_value = 0
+
+        if 'convert_type' in request.POST:
+          convert_type = int(request.POST["convert_type"])
+        if 'channel_no' in request.POST:
+          channel_no = int(request.POST["channel_type"])
+        if 'freq_type' in request.POST:
+          freq_value = int(request.POST["freq_type"])
+
         splitted_filename = list(os.path.splitext(filename))[0]  # converted filename without ext
 
         logger.debug("convert audio : %s->%s" % (str(ext), CONVERT_TYPE_CHK[convert_type]))
